using System;
using System.Collections.Generic;
using System.Text;

namespace PAT
{
    /// <summary>
    /// The math library that can be used in your model.
    /// all methods should be declared as public static.
    /// The return type can be bool and int only.
    /// 
    /// The method name will be used directly in your model.
    /// e.g. call(max, 10, 2), call(dominate, 3, 2);
    /// </summary>
    public class MathFunctions
    {
        private static List<int[]> Matrix;

        //dominate(v,w) == CHOOSE x \in 1..7 : GT(x, v) /\ GT(x, w)
        public static int dominate(int v, int w)
        {
            for (int i = 1; i <= 7; i++)
            {
                if (matrix[i - 1][v - 1] == 1 && matrix[i - 1][w - 1] == 1)
                {
                    return i;
                }
            }
            return -1;
        }

        //GT(v,w) == (Edges[v][w]=1)
        public static bool mailorder(int v, int w)
        {
            return matrix[v - 1][w - 1] == 1; 
        }

        private static List<int[]> matrix
        {
            get
            {
                if (Matrix == null)
                {
                    Matrix = new List<int[]>(7);
                    Matrix.Add(new int[] {0, 0, 1, 1, 1, 0, 0});
                    Matrix.Add(new int[] {1, 0, 1, 0, 0, 0, 1});
                    Matrix.Add(new int[] {0, 0, 0, 0, 1, 1, 1});
                    Matrix.Add(new int[] {0, 1, 1, 0, 0, 1, 0});
                    Matrix.Add(new int[] {0, 1, 0, 1, 0, 0, 1});
                    Matrix.Add(new int[] {1, 1, 0, 0, 1, 0, 0});
                    Matrix.Add(new int[] {1, 0, 0, 1, 0, 1, 0});
                }
                return Matrix;
            }
        }
    }
}
